@@ -5,9 +5,9 @@ template project is used to generate a target project.
 """
 #!/usr/bin/env python3
 
+import json
 import shutil
 import os
-import re
 import subprocess
 import sys
 import typing as t
@@ -15,7 +15,11 @@ from collections import OrderedDict
 from copy import copy
 from os import path
 from pathlib import Path
-from git import Actor, Repo
+try:
+    from git import Actor, Repo
+except ImportError as error:
+    print(error)
+    print("Please do 'pip install gitpython' and/or install git binary on host (ie machine, docker)")
 from cookiecutter_python.backend.gen_docs_common import get_docs_gen_internal_config
 from cookiecutter_python._logging_config import FILE_TARGET_LOGS
 
@@ -41,18 +45,11 @@ def get_context() -> OrderedDict:
 
 def get_request():
     cookie_dict: OrderedDict = get_context()
-    INITIALIZE_GIT_REPO_FLAG = "{{ cookiecutter.initialize_git_repo|lower }}"
-
-    # DATA: str to value mapping
     data: t.Dict[str, t.Any] = {
-        'cookiecutter': cookie_dict,
+        'vars': cookie_dict,
         'project_dir': GEN_PROJ_LOC,
         'module_name': cookie_dict['pkg_name'],
-        'author': "{{ cookiecutter.author }}",
-        'author_email': "{{ cookiecutter.author_email }}",
-        'initialize_git_repo': {'yes': True}.get(INITIALIZE_GIT_REPO_FLAG, False),
-        'project_type': "{{ cookiecutter.project_type }}",
-        # 'add_cli': {'module+cli': True}.get(project_type, False),
+        'initialize_git_repo': {'yes': True}.get(cookie_dict['initialize_git_repo'].lower(), False),
         'repo': None,
         # Docs Website: build/infra config, and Content Templates
         'docs_website': {
@@ -62,21 +59,7 @@ def get_request():
         # internally used to get the template folder of each Doc Builder
         'docs_extra_info': DOCS,
     }
-    # sanity check on data dict for docs_website and docs_extra_info
-    # TODO: remove sanity checks
-    assert 'docs_website' in data.keys(), f"ERROR 1: 'docs_website' not in data.keys()={data.keys()}"
-    assert 'builder' in data['docs_website'].keys(), f"ERROR 2: 'builder' not in data['docs_website'].keys()={data['docs_website'].keys()}"
-    assert 'docs_extra_info' in data.keys(), f"ERROR 3a: 'docs_extra_info' not in data.keys()={data.keys()}"
-    assert data['docs_website']['builder'] in {'mkdocs', 'sphinx'}, f"ERROR 3b: docs_website.builder={data['docs_website']['builder']} not in ['mkdocs', 'sphinx']"
-
-    from pprint import pprint
-    pprint("\n\n")
-    pprint(data)
-    assert data['docs_website']['builder'] in data['docs_extra_info'].keys(), f"ERROR 3: docs_website.builder={data['docs_website']['builder']} not in docs_extra_info.keys()={data['docs_extra_info'].keys()}"
-    request = type('PostGenProjectRequest', (), data)
-    assert hasattr(request, 'docs_extra_info')
-    assert hasattr(request, 'docs_website')
-    return request
+    return type('PostGenProjectRequest', (), data)
 
 
 class PostFileRemovalError(Exception):
@@ -110,6 +93,26 @@ delete_files = {
     'module+cli': lambda x: PYTEST_PLUGIN_ONLY(x),
 }
 
+### Define specialized files present per 'CI/CD option' ###
+CICD_DELETE = {
+    'stable': [
+        ('.github', 'workflows', 'cicd.yml'),
+        ('.github', 'workflows', 'codecov-upload.yml'),
+        ('.github', 'workflows', 'signal-deploy.yml'),
+    ],
+    'experimental': [
+        ('.github', 'workflows', 'test.yaml'),
+    ],
+}
+
+#     ('.github', 'workflows', 'test.yml'),
+# ]
+# CICD_STABLE_EXPERIMENTAL = lambda x: [
+#     ('.github', 'workflows', 'cicd.yml'),
+#     ('.github', 'workflows', 'codecov-upload.yml'),
+#     ('.github', 'workflows', 'signal-deploy.yml'),
+# ]
+
 # TODO: read from cookiecuuter['_template'] / cookiecutter.json
 # delete mkdocs.yml if not using mkdocs
 # delete sphinx files if not using sphinx
@@ -125,21 +128,33 @@ def post_file_removal(request):
 
     Delete files that are not relevant to the project type requested to
     generate.
-    
+
     For example, if the user requested a 'module' project type,
     then delete the files that are only relevant to a 'module+cli' project.
 
+    Deletes Files according to CI/CD Pipeline option [stable, experimental]
+
     Args:
         request ([type]): [description]
     """
     from pathlib import Path
-    
+    IRELEVANT_CI_CD_FILES: t.Iterable[t.Tuple[str, ...]] = CICD_DELETE[request.vars['cicd']]
+
     files_to_remove = [
-        os.path.join(request.project_dir, *x) for x in delete_files[request.project_type](request)
+        ## Post-Gen File Removal, given 'Project Type', 
+        os.path.join(request.project_dir, *x) for x in delete_files[request.vars['project_type']](request)
+    ] + [
+        ## Remove test.tml or cicd.yml based on CI/CD Option ##
+        os.path.join(request.project_dir, *path_components) for path_components
+        in IRELEVANT_CI_CD_FILES
     ]
-    ## Post Removal, given 'Project Type', of potentially extra files ##
     for file in files_to_remove:
-        os.remove(file)
+        try:
+            os.remove(file)
+        except FileNotFoundError as error:
+            print(f"** Could not remove '{file}'")
+            print('Exception: ' + str(error))
+            raise PostFileRemovalError(error)
 
     ## Remove gen 'docs' folders, given 'Docs Website Builder' (DWB) ##
     for builder_id, gen_docs_folder_name in request.docs_extra_info.items():
@@ -152,52 +167,43 @@ def post_file_removal(request):
             for file in files:
                 os.remove(os.path.join(request.project_dir, file))
 
-    ## Remove Generator Log file, found inside the Generated Project ##
-    # this happens, based on our _logging.py configuration, which probably causes
-    # the cookiecutter code to inherit this Logger. Then probably, cookiecutter
-    # changes the CWD at runtime when it renders the Templates, and thus a log
-    # file is created inside the Generated Project Folder.
+
+def _take_care_of_logs(logs_file: Path):
+    """Remove accidental App Log file, if found inside the Generated Project.
+
+    Ensures that only the Template Files are part of the Generated Projects by
+    removing any log file that might have been created during the Generation
+    process.
+
+    The application (generator) logs are configured at runtime in _logging.py
+    which could cause the cookiecutter's code to inherit our root Logger.
     
+    Then probably, cookiecutter changes the CWD at runtime when it renders the
+    Templates, and thus a log file is created inside the Generated Project
+    Folder, too.
+
     # Note: at Generator runtime, the user should still expect Captured Logs to
     # be written a File in their Shell's PWD, as designed and intented.
-
+    """
     # remove the log file, if it exists and it is empty
-    logs_file: Path = Path(request.project_dir) / FILE_TARGET_LOGS
     if logs_file.exists():
         # unintentional behaviour, is still happening
         if logs_file.stat().st_size == 0:  # at least expect empty log file
-            # safely remove the empty log file
-            try:
+            try:  # safely remove the empty log file
                 logs_file.unlink()
-            # windows erro reported on CI
-            # PermissionError: [WinError 32] The process cannot access the file because it is being used by another process
-            except PermissionError as e:
-                print(f"[WARNING]: {e}")
-                print(f"[WARNING]: Could not remove empty log file: {logs_file}")
-                print("[WARNING]: Please remove it manually, if you wish to do so.")
+            except PermissionError as e:  # has happened on Windows CI
+                # PermissionError: [WinError 32] The process cannot access the
+                # file because it is being used by another process
+                logger.debug("Permission Error, when removing empty log file: %s", json.dumps({
+                    'file': str(logs_file),
+                    'error': str(e),
+                    'platform': str(sys.platform),
+                }, indent=4, sort_keys=True))
         else:  # captured logs were written in the file: shy from removing it
             # Tell user about this, and let them decide what to do
             print(f"[INFO]: Captured Logs were written in {logs_file}")
 
 
-def _get_run_parameters(python3_minor: int):
-    def run(args: list, kwargs: dict):
-        return subprocess.run(*args, **dict(kwargs, check=True)) # pylint: disable=W1510 #nosec
-    def _subprocess_run(get_params):
-        def run1(*args, **kwargs):
-            return run(*get_params(*args, **kwargs))
-        return run1
-
-    return {
-        'legacy': _subprocess_run(run_process_python36_n_below),
-        'new': _subprocess_run(run_process_python37_n_above),
-    }[
-        {True: 'legacy', False: 'new'}[
-            python3_minor < 7  # is legacy Python 3.x version (ie 3.5 or 3.6) ?
-        ]
-    ]
-
-
 def run_process_python37_n_above(*args, **kwargs):
     return [args], dict(capture_output=True, check=True, **kwargs)
 
@@ -206,7 +212,21 @@ def run_process_python36_n_below(*args, **kwargs):
 
 
 def subprocess_run(*args, **kwargs):
-    return _get_run_parameters(sys.version_info.minor)(*args, **kwargs)
+    def _subprocess_run(get_params):
+        def run1(*args, **kwargs):
+            args_list, kwargs_dict = get_params(*args, **kwargs)
+            return subprocess.run(*args_list, **dict(kwargs_dict, check=True)) # pylint: disable=W1510 #nosec
+        return run1
+
+    d = {
+        'legacy': _subprocess_run(run_process_python36_n_below),
+        'new': _subprocess_run(run_process_python37_n_above),
+    }[
+        {True: 'legacy', False: 'new'}[
+            sys.version_info.minor < 7  # is legacy Python 3.x version (ie 3.5 or 3.6) ?
+        ]
+    ]
+    return d(*args, **kwargs)
 
 
 def initialize_git_repo(project_dir: str):
@@ -216,25 +236,6 @@ def initialize_git_repo(project_dir: str):
     subprocess_run('git', 'init', cwd=project_dir)
 
 
-def exception(subprocess_exception: subprocess.CalledProcessError):
-    error_message = str(subprocess_exception.stderr, encoding='utf-8')
-    if re.match(r'error: could not lock config file .+\.gitconfig File exists',
-        error_message):
-        return type('LockFileError', (Exception,), {})(error_message)
-    return subprocess_exception
-
-def grant_basic_permissions(project_dir: str):
-    try:
-        return subprocess_run(
-            'git', 'config', '--global', '--add', 'safe.directory', str(project_dir),
-            cwd=project_dir,
-        )
-    except subprocess.CalledProcessError as error:
-        print('Did not add an entry in ~/.gitconfig!')
-        print(str(error.stderr, encoding='utf-8'))
-        print(exception(error))
-
-
 def iter_files(request):
     path_obj = Path(request.project_dir)
     for file_path in path_obj.rglob('*'):
@@ -250,7 +251,7 @@ def iter_files(request):
 def git_commit(request):
     """Commit the staged changes in the generated project."""
     cookiecutter_config_str = (
-        '\n'.join((f"  {key}: {val}" for key, val in request.cookiecutter.items())) + '\n'
+        '\n'.join((f"  {key}: {val}" for key, val in request.vars.items())) + '\n'
     )
     commit_message = (
         "Template applied from"
@@ -263,7 +264,7 @@ def git_commit(request):
     request.repo.index.add(list(
         iter((path.relpath(x, start=request.project_dir) for x in iter_files(request)))
     ))
-    author = Actor(request.author, request.author_email)
+    author = Actor(request.vars['author'], request.vars['author_email'])
 
     request.repo.index.commit(
         commit_message,
@@ -290,13 +291,16 @@ def is_git_repo_clean(project_directory: str) -> bool:
     return False
 
 
-def _post_hook():
+def post_hook():
     """Delete irrelevant to Project Type files and optionally do git commit."""
     request = get_request()
     # Delete gen Files related to
     #  - different Project Type
     #  - related to different documentation builder tool"""
     post_file_removal(request)
+    # remove "unintentional logs" file, if it exists and it is empty
+    _take_care_of_logs(Path(request.project_dir) / FILE_TARGET_LOGS)
+
     # move/rename docs-builder-specific docs folder to 'docs/'
     try:
         # ie for mkdocs: `mv docs-mkdocs docs`, ie for sphinx: `mv docs-sphinx docs`
@@ -311,24 +315,21 @@ def _post_hook():
 
     # Git commit
     if request.initialize_git_repo:
-        initialize_git_repo(request.project_dir)
-        # grant_basic_permissions(request.project_dir)
-        request.repo = Repo(request.project_dir)
-        if not is_git_repo_clean(request.project_dir):
-            git_commit(request)
-        else:
-            print('No changes to commit.')
+        try:
+            initialize_git_repo(request.project_dir)
+            request.repo = Repo(request.project_dir)
+            if not is_git_repo_clean(request.project_dir):
+                git_commit(request)
+            else:
+                print('No changes to commit.')
+        except Exception as error:
+            print('Exception: ' + str(error))
     return 0
 
 
-def post_hook():
-    """Delete irrelevant to Project Type files and optionally do git commit."""
-    sys.exit(_post_hook())
-
-
 def main():
     """Delete irrelevant to Project Type files and optionally do git commit."""
-    post_hook()
+    sys.exit(post_hook())
 
 
 if __name__ == "__main__":
