@@ -112,8 +112,29 @@ def project_dir(generate_project, distro_loc, tmpdir):
     return proj_dir
 
 
+## NEW REQUEST FACTORY
+
+
+class EmulatedRequest(t.Protocol):
+
+    project_dir: t.Union[str, None]
+    cookiecutter: t.Optional[t.Dict]
+    author: t.Optional[str]
+    author_email: t.Optional[str]
+    initialize_git_repo: t.Optional[bool]
+    interpreters: t.Optional[t.Dict]
+    project_type: t.Optional[str]
+    module_name: t.Optional[str]
+    cicd: t.Optional[str]
+
+
+class EmulatedRequestFactory(t.Protocol):
+    def pre(**kwargs: t.Any) -> EmulatedRequest: ...
+    def post(**kwargs: t.Any) -> EmulatedRequest: ...
+
+
 @pytest.fixture
-def hook_request_new(distro_loc):
+def request_factory(distro_loc) -> t.Type[EmulatedRequestFactory]:
     """Emulate the templated data used in the 'pre' and 'post' hooks scripts.
 
     MUST be kept in SYNC with the 'pre' and 'post' hook scripts, and their
@@ -192,8 +213,9 @@ def hook_request_new(distro_loc):
     assert engine_state_vars_supported_by_td
 
     # WHEN we define a way to create a valid input for pre and post hooks
+
     @attr.s(auto_attribs=True, kw_only=True)
-    class HookRequest:
+    class EmulatedHookRequest:
         """Hook Request Data Class.
 
         This class is used to mock the 'templated variables' that are used in
@@ -223,19 +245,21 @@ def hook_request_new(distro_loc):
             interpreters (t.Optional[t.Dict]): [description]
             project_type (t.Optional[str]): [description]
             module_name (t.Optional[str]): [description]
+            cicd (t.Optional[str]): [description]
         """
 
         project_dir: t.Optional[str]
         # TODO improvement: add key/value types
         ### We want to skip running the templating engine, so we mock the state
         ### that the templating engine would have produced.
-        cookiecutter: t.Optional[t.Dict] = attr.ib(
+
+        # Templated Vars (cookiecutter) use in Context for Jinja Rendering
+        vars: t.Optional[t.Dict] = attr.ib(
+            # IMPORTANT: emulates jinja context vars (ie from list of choices to 1st choice)
             default=OrderedDict(td_cookiecutter_json_data, **engine_state['cookiecutter'])
         )
-        author: t.Optional[str] = attr.ib(default='Konstantinos Lampridis')
-        author_email: t.Optional[str] = attr.ib(default='boromir674@hotmail.com')
         initialize_git_repo: t.Optional[bool] = attr.ib(default=True)
-        interpreters: t.Optional[t.Dict] = attr.ib(
+        interpreters: t.Optional[t.List[str]] = attr.ib(
             default=[
                 '3.6',
                 '3.7',
@@ -253,7 +277,7 @@ def hook_request_new(distro_loc):
             )
         )
         package_version_string: t.Optional[str] = attr.ib(default='0.0.1')
-        docs_extra_info: t.Optional[bool] = attr.ib(
+        docs_extra_info: t.Optional[t.Dict[str, str]] = attr.ib(
             default=dict(
                 **{'mkdocs': 'docs-mkdocs', 'sphinx': 'docs-sphinx'},
             )
@@ -264,27 +288,33 @@ def hook_request_new(distro_loc):
                 'python_runtime': '3.10',
             }
         )
+        cicd: t.Optional[str] = attr.ib(default='stable')
 
-    class BaseHookRequest(metaclass=SubclassRegistry):
+        # add entries to this to fix tests/test_post_hook.py after prod code advances
+        def __attrs_post_init__(self):
+            """IMPORTANT: emulate jinja context vars (ie from list of choices to 1st choice)"""
+            # self.vars is available at Generator runtime.
+            # so populate values here to allow control per test case
+            self.vars['project_type'] = self.project_type
+            self.vars['cicd'] = self.cicd
+
+    class HookRequest(metaclass=SubclassRegistry):
         pass
 
     @attr.s(auto_attribs=True, kw_only=True)
-    @BaseHookRequest.register_as_subclass('pre')
-    class PreGenProjectRequest(HookRequest):
+    @HookRequest.register_as_subclass('pre')
+    class PreGenProjectRequest(EmulatedHookRequest):
         project_dir: str = attr.ib(default=None)
 
-    @BaseHookRequest.register_as_subclass('post')
-    class PostGenProjectRequest(HookRequest):
+    @HookRequest.register_as_subclass('post')
+    class PostGenProjectRequest(EmulatedHookRequest):
         pass
 
-    return BaseHookRequest
-
-
-@pytest.fixture
-def request_factory(hook_request_new):
-    def create_request_function(type_id: str):
-        def _create_request(self, **kwargs):
-            return hook_request_new.create(type_id, **kwargs)
+    # Adapting exposed interface
+    def get_create_request_func(type_id: str) -> t.Callable[..., EmulatedHookRequest]:
+        def _create_request(**kwargs):
+            ret: EmulatedHookRequest = HookRequest.create(type_id, **kwargs)
+            return ret
 
         return _create_request
 
@@ -292,10 +322,13 @@ def request_factory(hook_request_new):
         'RequestFactory',
         (),
         {
-            'pre': create_request_function('pre'),
-            'post': create_request_function('post'),
+            'pre': get_create_request_func('pre'),
+            'post': get_create_request_func('post'),
         },
-    )()
+    )
+
+
+### END
 
 
 @pytest.fixture
@@ -642,6 +675,8 @@ def user_config(distro_loc: Path) -> ConfigInterfaceGeneric[ConfigProtocol]:
                 data['docs_builder'] = data['docs_builder'][0]  # choice variable
                 # RTD CI Python Version #
                 data['rtd_python_version'] = data['rtd_python_version'][0]  # choice variable
+                # CICD Pipeline Design old/new , stable/experimental
+                data['cicd'] = data['cicd'][0]  # choice variable
                 return data
 
             return _load_json
@@ -806,18 +841,19 @@ def get_expected_generated_files(
         ii = [
             x
             for x in proj_type_2_files_to_remove[expected_project_type](
-                type(
-                    'PostGenRequestLike',
-                    (),
-                    {
-                        'module_name': pkg_name,
-                    },
-                )
+                type('PostGenRequestLike', (), {'module_name': pkg_name})
             )
         ]
         SEP = '/'
         files_to_remove: t.Set[str] = {SEP.join(i) for i in ii}
 
+        # Augment the expected files for removal based on CI/CD option
+        from cookiecutter_python.hooks.post_gen_project import CICD_DELETE
+
+        files_to_remove.update(
+            [os.path.join(*parts) for parts in CICD_DELETE[config.data.get('cicd', 'stable')]]
+        )
+
         ## DERIVE expected files inside 'docs' gen dir
         from cookiecutter_python.backend import get_docs_gen_internal_config
 
@@ -873,7 +909,8 @@ def get_expected_generated_files(
             [isinstance(x, str) for x in files_to_remove]
         ), f"Temporary Requirement of Test Code: files_to_remove must be a list of strings, not {files_to_remove}"
 
-        ## Remove all Template Docs files from Expectations
+        ## Remove all Template Docs files from Expectations, because in the Template Project
+        # 2 dedicated foldres are used to maintain mkdocs and spinx Docs (which get moved to ./docs in post hook)
         for (
             docs_builder_id,
             builder_docs_folder_name,
@@ -989,7 +1026,7 @@ def get_expected_generated_files(
         res = []
         for x in expected_gen_files:
             parts = x.parts
-            assert type(parts) == tuple, f"Sanity check fail: {parts}"
+            assert type(parts) is tuple, f"Sanity check fail: {parts}"
             assert len(parts) > 0, f"Sanity check fail: {parts}"
             b = SEP.join(parts)
             b = b.replace(r'{{ cookiecutter.pkg_name }}', pkg_name).replace(
@@ -1037,7 +1074,13 @@ def assert_commit_author_is_expected_author(assert_initialized_git):
 
 @pytest.fixture
 def assert_initialized_git():
-    from git import Repo
+    try:
+        from git import Repo
+    except ImportError as error:
+        # happens if git binary is not installed on host!
+        print("Error: ", error)
+        return lambda x: 'git binary not installed on host'
+
     from git.exc import InvalidGitRepositoryError
 
     def _assert_initialized_git(folder: str):
@@ -1074,6 +1117,8 @@ def assert_files_committed_if_flag_is_on(
         print("\n HERE")
         try:
             repo = assert_initialized_git(folder)
+            if repo == 'git binary not installed on host':
+                return
 
             head = repo.active_branch.commit
             assert head
