@@ -60,9 +60,11 @@ def test_prehook_sanitization_throws_error_on_duplicate_interpreters():
 
 
 def test_prehook_sanitization_throws_error_on_unsupported_interpreters():
-    from cookiecutter_python.backend.sanitization.interpreters_support import SUPPORTED
+    from cookiecutter_python.backend.sanitization.interpreters_support import (
+        VALID_PYTHON_VERSIONS,
+    )
 
-    SUPPORTED_SET: t.Set[str] = SUPPORTED
+    SUPPORTED_SET: t.Set[str] = VALID_PYTHON_VERSIONS
     unsupported_interpreter = '3.5'
 
     # SANITY to make test case valid
